
# If you have problems with Croatian month names change locale:
Sys.setlocale("LC_TIME","English")

# Position of working directory
folder_home <- "D:\\Users\\Matija\\Dropbox\\FOC systemic risk in social media\\paper proposals\\Paper draft v5\\data"
setwd(folder_home)

library(ggplot2)
library(reshape)

# Plot NCI+occurrences+Google+semantic correlations with all financial indexes

# Column names can contain spaces so when refering to them you should use '' (or ``?) 
data <- read.csv("R.csv",sep=";",row.names=1,na.strings="NaN",check.names=FALSE)
data <- data[c(1:4,24:38),c(1:28)]

data$id = row.names(data)
data.m <- melt(data)

# Order levels the same as in csv file
data.m$X <- factor(data.m$id, levels=as.character(data$id))

p <- ggplot(data.m, aes(x=X,y=variable)) 
p <- p + geom_tile(aes(fill = value), colour = "white") + coord_flip()
p <- p + scale_fill_gradient2(name = "Correlation", low = "#cb181d", mid = "white", high = "#238b45", midpoint = 0, na.value = "grey80")
base_size <- 9
p <- p + theme_grey(base_size = base_size)
p <- p + labs(x = "",y = "")
p <- p + scale_x_discrete(expand = c(0, 0))
p <- p + scale_y_discrete(expand = c(0, 0))
p <- p + theme(axis.text.y=element_text(size=9))
p <- p + theme(axis.ticks = element_blank(), axis.text.x = element_text(size = 9, angle = 330, hjust = 0, colour = "grey50"))
p <- p + geom_text(aes(label=round(value,digits=2)),size=2.5)

pdf("R_nci_occurrences_google_semantic.pdf",width=15,height=7)
print(p)
dev.off()

# If postscript output is needed
postscript("R_nci_occurrences_google_semantic.eps",horizontal=FALSE,paper="special",width=15,height=7)
print(p)
dev.off()


# Plot p-values for correlations

data <- read.csv("p.csv",sep=";",row.names=1,na.strings="NaN",check.names=FALSE)
data <- data[c(1:4,24:38),c(1:28)]

data$id = row.names(data)
data.m <- melt(data)
data.m$X <- factor(data.m$id, levels=as.character(data$id))

data.m$p[data.m$value > 0.05] <- '0'
data.m$p[data.m$value <= 0.05] <- '*'
data.m$p[data.m$value <= 0.01] <- '**'
data.m$p[data.m$value <= 0.001] <- '***'

p <- ggplot(data.m, aes(x=X,y=variable)) 
p <- p + geom_tile(aes(fill = p), colour = "white") + coord_flip()
p <- p + scale_fill_manual(name="p-value level\\nfor correlations",values=c("0"="#fb6a4a","*"="#fc9272","**"="#fcbba1","***"="#fee5d9"),labels=c("p > 0.05","p < 0.05","p < 0.01","p < 0.001"),breaks=c("0","*","**","***"))
base_size <- 9
p <- p + theme_grey(base_size = base_size)
p <- p + labs(x = "",y = "")
p <- p + scale_x_discrete(expand = c(0, 0))
p <- p + scale_y_discrete(expand = c(0, 0))
p <- p + theme(axis.text.y=element_text(size=9))
p <- p + theme(axis.ticks = element_blank(), axis.text.x = element_text(size = 9, angle = 330, hjust = 0, colour = "grey50"))
p <- p + geom_text(aes(label=round(value,digits=3)),size=2)
# p

pdf("p_nci_occurrences_google_semantic.pdf",width=15,height=7)
print(p)
dev.off()

# If postscript output is needed
postscript("p_nci_occurrences_google_semantic.eps",horizontal=FALSE,paper="special",width=15,height=7)
print(p)
dev.off()

