
# If you have problems with Croatian month names change locale:
Sys.setlocale("LC_TIME","English")

# Position of working directory
folder_home <- "D:\\Users\\Matija\\Dropbox\\FOC systemic risk in social media\\paper proposals\\Paper draft v5\\data"
setwd(folder_home)

library(ggplot2)
library(reshape)
library(gridExtra)

# Column names can contain spaces so when refering to them you should use '' (or ``?) 
data <- read.csv("G.csv",sep=";",row.names=1,na.strings="NaN",check.names=FALSE)

data$id = row.names(data)
data.m <- melt(data)

# Order levels the same as in csv file
data.m$X <- factor(data.m$id, levels=as.character(data$id))

data.m$value <- factor(data.m$value)

# Reference for symbols http://www.adobe.com/products/postscript/pdfs/PLRM.pdf
generate_arrows <- function(m){
    ifelse(m==1,'symbol("\256")',
    ifelse(m==2,'symbol("\256 \256")',
    ifelse(m==3,'symbol("\255")',
    ifelse(m==4,'symbol("\255 \255")',
    ifelse(m==5,'symbol("\256 \255")',
    ifelse(m==6,'symbol("\256 \255 \255")',
    ifelse(m==7,'symbol("\256 \256 \255")','')))))))
}

data.m$direction[is.na(data.m$value)] <- '0'
data.m$direction[data.m$value %in% c(1,2)] <- '1'
data.m$direction[data.m$value %in% c(3,4)] <- '2'
data.m$direction[data.m$value %in% c(5,6,7)] <- '3'

p <- ggplot(data.m, aes(x=X,y=variable)) 
p <- p + geom_tile(aes(fill = direction), colour = "white") + coord_flip()
p <- p + scale_fill_manual(name="Direction and p-value\nlevel for Granger causality",
                           values=c("0"="grey95","1"="#bae4b3","2"="#fdbe85","3"="#bdd7e7"),
                           labels=c("no G-causality","X G-causes Y","Y G-causes X","G-causality in both directions"))
base_size <- 9
p <- p + theme_grey(base_size = base_size)
p <- p + labs(x = "X",y = "Y")
p <- p + scale_x_discrete(expand = c(0, 0))
p <- p + scale_y_discrete(expand = c(0, 0))
p <- p + theme(axis.text.y=element_text(size=9))
p <- p + theme(axis.ticks = element_blank(), axis.text.x = element_text(size = 9, angle = 330, hjust = 0, colour = "grey50"))
p <- p + geom_text(aes(label=generate_arrows(value)),size=3,parse=TRUE)
p <- p + theme(legend.title=element_text(size=9),legend.text=element_text(size=9))
p <- p + annotate("text",x=6,y=24,hjust=-0.8,label='symbol("\255")~~p-value<0.05',size=3,parse=TRUE)
p <- p + annotate("text",x=5,y=24,hjust=-0.6,label='symbol("\255 \255")~~p-value<0.01',size=3,parse=TRUE)
# p

# Override clipping for additional dummy legend
pdf("G_nci_occurrences_google_semantic.pdf",width=15,height=6)
gt <- ggplot_gtable(ggplot_build(p))
gt$layout$clip[gt$layout$name=="panel"] <- "off"
grid.draw(gt)
dev.off()

# If postscript output is needed
postscript("G_nci_occurrences_google_semantic.eps",horizontal=FALSE,paper="special",width=15,height=6)
gt <- ggplot_gtable(ggplot_build(p))
gt$layout$clip[gt$layout$name=="panel"] <- "off"
grid.draw(gt)
dev.off()

