
# If you have problems with Croatian month names change locale:
Sys.setlocale("LC_TIME","English")

# Position of working directory
folder_home <- "D:\\Users\\Matija\\Dropbox\\FOC systemic risk in social media\\paper proposals\\Paper draft v5\\data"
setwd(folder_home)

library(ggplot2)
library(reshape)
library(gridExtra)
library(scales)
source("ggplot2CustomThemes.R") # Custom themes for ggplot2

# Column names can contain spaces so when refering to them you should use '' (or ``?) 
indexes <- read.csv("semantic_components_occurrences.csv",sep=";",na.strings="NaN",check.names=FALSE,stringsAsFactors=FALSE)

# Manual wrapping of long labels
indexes$`[company] entities`[25] <- 'The Royal Bank of\nScotland Group PLC'
indexes$`[instrument] entities`[4] <- 'DOW JONES INDUSTRIAL\nAVERAGE'
indexes$`[eurocrisis] entities`[7] <- 'federal reserve limited\nliability companies'

# Order levels the same as in csv file (i.e. how we loaded the in dataframe)
indexes$`[company] entities` <- factor(indexes$`[company] entities`, levels=rev(as.character(indexes$`[company] entities`)))
indexes$`[region] entities` <- factor(indexes$`[region] entities`, levels=rev(as.character(indexes$`[region] entities`)))
indexes$`[instrument] entities` <- factor(indexes$`[instrument] entities`, levels=rev(as.character(indexes$`[instrument] entities`)))
indexes$`[eurocrisis] entities` <- factor(indexes$`[eurocrisis] entities`, levels=rev(as.character(indexes$`[eurocrisis] entities`)))

# NOTE: When coordinates are flipped it appears that theme still uses nonflipped
# version of x and y axes, while xlab and ylab use flipped version.

p1 <- ggplot(indexes[c("[company] entities","[company] percentages")],aes(x=`[company] entities`,y=`[company] percentages`)) 
p1 <- p1 + geom_bar(stat="identity",fill="#0072B2",width=0.7) + coord_flip() + theme_custom()
p1 <- p1 + scale_y_continuous(labels = function (x) paste(floor(x),'%',sep=''))
p1 <- p1 + theme(axis.title.y=element_blank()) + ylab("percentage of financial documents")
p1 <- p1 + theme(axis.text.y=element_text(size=10))
p1 <- p1 + theme(axis.title.x=element_text(size=9))
p1 <- p1 + theme(plot.title=element_text(size=12))
p1 <- p1 + theme(axis.ticks = element_line(size = 0.2))
p1 <- p1 + theme(plot.margin = unit(c(0.6,0.1,0.6,0),"cm")) # top, right, bottom, left
p1 <- p1 + ggtitle("Company entities")

p2 <- ggplot(indexes[c("[region] entities","[region] percentages")],aes(x=`[region] entities`,y=`[region] percentages`)) 
p2 <- p2 + geom_bar(stat="identity",fill="#0072B2",width=0.7) + coord_flip() + theme_custom()
p2 <- p2 + scale_y_continuous(labels = function (x) paste(floor(x),'%',sep=''))
p2 <- p2 + theme(axis.title.y=element_blank()) + ylab("percentage of financial documents")
p2 <- p2 + theme(axis.text.y=element_text(size=10))
p2 <- p2 + theme(axis.title.x=element_text(size=9))
p2 <- p2 + theme(plot.title=element_text(size=12))
p2 <- p2 + theme(axis.ticks = element_line(size = 0.2))
p2 <- p2 + theme(plot.margin = unit(c(0.6,0.1,0.6,0),"cm")) # top, right, bottom, left
p2 <- p2 + ggtitle("Region entities")

p3 <- ggplot(indexes[c("[instrument] entities","[instrument] percentages")],aes(x=`[instrument] entities`,y=`[instrument] percentages`)) 
p3 <- p3 + geom_bar(stat="identity",fill="#0072B2",width=0.7) + coord_flip() + theme_custom()
p3 <- p3 + scale_y_continuous(labels = function (x) paste(floor(x),'%',sep=''))
p3 <- p3 + theme(axis.title.y=element_blank()) + ylab("percentage of financial documents")
p3 <- p3 + theme(axis.text.y=element_text(size=10))
p3 <- p3 + theme(axis.title.x=element_text(size=9))
p3 <- p3 + theme(plot.title=element_text(size=12))
p3 <- p3 + theme(axis.ticks = element_line(size = 0.2))
p3 <- p3 + theme(plot.margin = unit(c(0.6,0.1,0.6,0),"cm")) # top, right, bottom, left
p3 <- p3 + ggtitle("Instrument entities")

p4 <- ggplot(indexes[c("[eurocrisis] entities","[eurocrisis] percentages")],aes(x=`[eurocrisis] entities`,y=`[eurocrisis] percentages`)) 
p4 <- p4 + geom_bar(stat="identity",fill="#0072B2",width=0.7) + coord_flip() + theme_custom()
p4 <- p4 + scale_y_continuous(labels = function (x) paste(floor(x),'%',sep=''))
p4 <- p4 + theme(axis.title.y=element_blank()) + ylab("percentage of financial documents")
p4 <- p4 + theme(axis.text.y=element_text(size=10))
p4 <- p4 + theme(axis.title.x=element_text(size=9))
p4 <- p4 + theme(plot.title=element_text(size=12))
p4 <- p4 + theme(axis.ticks = element_line(size = 0.2))
p4 <- p4 + theme(plot.margin = unit(c(0.6,0.5,0.6,0),"cm")) # top, right, bottom, left
p4 <- p4 + ggtitle("Eurocrisis entities")

pdf("semantic_components_occurrences.pdf",width=15,height=7)
grid.arrange(p1,p2,p3,p4,widths=c(1,0.9,1,1),ncol=4)
dev.off()

# If postscript output is needed
postscript("semantic_components_occurrences.eps",horizontal=FALSE,paper="special",width=15,height=7)
grid.arrange(p1,p2,p3,p4,widths=c(1.1,0.9,1.1,1.2),ncol=4)
dev.off()

