
# If you have problems with Croatian month names change locale:
Sys.setlocale("LC_TIME","English")

# Position of working directory
folder_home <- "D:\\Users\\Matija\\Dropbox\\FOC systemic risk in social media\\paper proposals\\Paper draft v5\\data"
setwd(folder_home)

library(ggplot2)
library(reshape)
library(gridExtra)
library(scales)
source("ggplot2CustomThemes.R") # Custom themes for ggplot2

# Column names can contain spaces so when refering to them you should use '' (or ``?) 
indexes <- read.csv("indexes.csv",sep=";",row.names=1,na.strings="NaN",check.names=FALSE)
indexes$date = as.Date(row.names(indexes),"%d.%m.%Y")

normalit<-function(m){
     (m - min(m,na.rm=TRUE))/(max(m,na.rm=TRUE)-min(m,na.rm=TRUE))
}

chosen_indexes <- c("NCI","NCI financial","VIX")
indexes_norm <- as.data.frame(apply(indexes[chosen_indexes],2,normalit))
indexes_norm$date = as.Date(row.names(indexes_norm),"%d.%m.%Y")

indexes1 <- melt(indexes_norm, id="date", measure=c("VIX","NCI"))
p1 <- ggplot(indexes1, aes(x=as.Date(date,"%d.%m.%Y"),y=value,color=variable))
p1 <- p1 + geom_line(width=0.5) + geom_point(size=1.5) + theme_custom()
p1 <- p1 + scale_x_date(breaks=date_breaks("2 months"),labels=date_format("%b %y"))
p1 <- p1 + scale_colour_brewer(name="Legend",labels=c("VIX","NCI"),palette="Set1")
p1 <- p1 + labs(x = "dates",y = "value")
p1 <- p1 + theme(legend.key=element_blank())

indexes2 <- melt(indexes_norm, id="date", measure=c("VIX","NCI financial"))
p2 <- ggplot(indexes2, aes(x=as.Date(date,"%d.%m.%Y"),y=value,color=variable))
p2 <- p2 + geom_line(width=0.5) + geom_point(size=1.5) + theme_custom()
p2 <- p2 + scale_x_date(breaks=date_breaks("2 months"),labels=date_format("%b %y"))
p2 <- p2 + scale_colour_brewer(name="Legend",labels=c("VIX","NCI (financial documents)"),palette="Set1")
p2 <- p2 + labs(x = "dates",y = "normalized value")
p2 <- p2 + theme(legend.key=element_blank())

temp <- cor(indexes[c("NCI","VIX")],method="pearson",use="pairwise.complete.obs")
p4 <- ggplot(indexes[c("NCI","VIX")],aes(x=`NCI`,y=VIX)) 
p4 <- p4 + geom_point(size=1.5) + theme_custom()
p4 <- p4 + annotate("text", x = max(indexes["NCI"],na.rm=true), y = max(indexes["VIX"],na.rm=true), label = paste("R = ",format(temp[1,2],digits=3),sep=''), size=3, hjust=1)

temp <- cor(indexes[c("NCI financial","VIX")],method="pearson",use="pairwise.complete.obs")
p5 <- ggplot(indexes[c("NCI financial","VIX")],aes(x=`NCI financial`,y=VIX)) 
p5 <- p5 + geom_point(size=1.5) + theme_custom()
p5 <- p5 + xlab("NCI on financial documents")
p5 <- p5 + annotate("text", x = max(indexes["NCI financial"],na.rm=true), y = max(indexes["VIX"],na.rm=true), label = paste("R = ",format(temp[1,2],digits=3),sep=''), size=3, hjust=1)

pdf("NCI_vs_VIX.pdf",width=16,height=8)
grid.arrange(arrangeGrob(p1,p4,widths=c(3/4,1/4),ncol=2),arrangeGrob(p2,p5,widths=c(3/4,1/4),ncol=2),ncol=1)
dev.off()

# If postscript output is needed
postscript("NCI_vs_VIX.eps",horizontal=FALSE,paper="special",width=15,height=7)
grid.arrange(arrangeGrob(p1,p4,widths=c(3/4,1/4),ncol=2),arrangeGrob(p2,p5,widths=c(3/4,1/4),ncol=2),ncol=1)
dev.off()

